"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnaryCall = void 0;
/**
 * A unary RPC call. Unary means there is exactly one input message and
 * exactly one output message unless an error occurred.
 */
class UnaryCall {
    constructor(serviceInfo, methodInfo, requestHeaders, requestMessage, responseHeaders, responseMessage, responseStatus, responseTrailers, cancelFn) {
        this.serviceInfo = serviceInfo;
        this.methodInfo = methodInfo;
        this.requestType = methodInfo.I;
        this.responseType = methodInfo.O;
        this.requestHeaders = requestHeaders;
        this.requestMessage = requestMessage;
        this.responseHeaders = responseHeaders;
        this.responseMessage = responseMessage;
        this.responseStatus = responseStatus;
        this.responseTrailers = responseTrailers;
        this.cancelFn = cancelFn;
    }
    /**
     * Cancel this call.
     */
    cancel() {
        this.cancelFn();
    }
    /**
     * If you are only interested in the final outcome of this call,
     * you can await it to receive a `FinishedUnaryCall`.
     */
    then(onfulfilled, onrejected) {
        return this.promiseFinished().then(value => onfulfilled ? Promise.resolve(onfulfilled(value)) : value, reason => onrejected ? Promise.resolve(onrejected(reason)) : Promise.reject(reason));
    }
    promiseFinished() {
        return __awaiter(this, void 0, void 0, function* () {
            let [responseHeaders, responseMessage, responseStatus, responseTrailers] = yield Promise.all([this.responseHeaders, this.responseMessage, this.responseStatus, this.responseTrailers]);
            return {
                serviceInfo: this.serviceInfo,
                methodInfo: this.methodInfo,
                requestType: this.requestType,
                responseType: this.responseType,
                requestHeaders: this.requestHeaders,
                requestMessage: this.requestMessage,
                responseHeaders,
                responseMessage,
                responseStatus,
                responseTrailers
            };
        });
    }
}
exports.UnaryCall = UnaryCall;
//# sourceMappingURL=unary-call.js.map